@@ -1,3 +1,4 @@
+from django.contrib.staticfiles.templatetags.staticfiles import static
 from braces.views import AjaxResponseMixin, JSONResponseMixin
 from braces.views._access import AccessMixin
 from django.utils import six
@@ -27,8 +28,10 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
     search_default = None
     _active_tag = None
     add_btn = True
+    visible_pages = 3
     add_button_url = '#'
     add_button_name = 'Add'
+    detail_url = None
     search_placeholder = None
     search_id = None
     table_id = None
@@ -38,6 +41,8 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
     css_div_header = None
     css_div_body = None
     css_div_footer = None
+    css_pagination = None
+    pagination_labels = {'prev':'<', 'next':'>', 'first':'<<', 'last':'>>'}
     _translate = {
         'search_placeholder': {
             'en-us': 'Search for',
@@ -101,7 +106,6 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
 
     def get_context_data(self, **kwargs):
         context = super(ListMixin, self).get_context_data(**kwargs)
-
         paginador = context['paginator'] if 'paginator' in context else None
         self.num_pages = 1
         if paginador:
@@ -232,7 +236,7 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
     def _footer(self):
         output = []
         output.append('<div class="{}">'.format(self.get_css_classes('div_footer')))
-        output.append('<ul id="pagination">')
+        output.append('<ul id="{}">'.format(self.get_css_classes('pagination')))
         output.append('</ul>')
         output.append('</div>')
         return ''.join(output)
@@ -243,8 +247,10 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
         search_id = self.get_search_id()
         add_args = ''.join([', {}'.format(column['lookup']) for column in self.get_columns()])[2:]
         td_columns = ''.join(
-            ["<td nowrap><a href=\"#\">'+ (({field} != null) ? {to_js_function} : '') +'</a></td>".format(
-                    field=column['lookup'], to_js_function=column['to_js_function']
+            ["<td nowrap><a href=\"{detail_url}\">'+ (({field} != null) ? {to_js_function} : '') +'</a></td>".format(
+                    field=column['lookup'],
+                    to_js_function=column['to_js_function'],
+                    detail_url=self.detail_url if self.detail_url else '#'
             ) for column in self.get_columns()]
         )
         update_columns = ''.join([', data[i]["{}"]'.format(column['lookup']) for column in self.get_columns()])[2:]
@@ -260,11 +266,17 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
         else:
             search_default = self.search_default[0]
 
+        detail_pk = ''
+        detail_pk_arg = ''
+        if self.detail_url:
+            detail_pk = 'id, '
+            detail_pk_arg = 'data[i]["id"], '
+
         return mark_safe("""
-            <link rel="stylesheet" href="/static/awesome_mixins/css/list_view.css">
-            <script src="/static/awesome_mixins/js/twbs-pagination/jquery.twbsPagination.min.js"></script>
+            <link rel="stylesheet" href="{awesome_css}">
+            <script src="{awesome_twbs}"></script>
             <script type="text/javascript">
-                function AmAddLine({add_args}){{
+                function AmAddLine({detail_pk}{add_args}){{
                     $("#{table_id} tbody").append(
                         '<tr>{td_columns}</tr>'
                     );
@@ -279,7 +291,7 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
                 function AmUpdateTable(data) {{
                     AmClearTable();
                     for(var i = 0; i < data.length; i++){{
-                        AmAddLine({update_columns});
+                        AmAddLine({detail_pk_arg}{update_columns});
                     }}
                 }}
 
@@ -348,11 +360,11 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
                                 $('#pagination').twbsPagination('destroy');
                                 $('#pagination').twbsPagination({{
                                     totalPages: data['num_pages'],
-                                    visiblePages: 3,
-                                    first: '<<',
-                                    prev: '<',
-                                    next: '>',
-                                    last: '>>',
+                                    visiblePages: {visible_pages},
+                                    first: '{pagination_labels_first}',
+                                    prev: '{pagination_labels_prev}',
+                                    next: '{pagination_labels_next}',
+                                    last: '{pagination_labels_last}',
                                     onPageClick: function (event, page) {{
                                         AmUpdatePage(page);
                                     }}
@@ -369,11 +381,11 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
                     $(window).load(function () {{
                         $('#pagination').twbsPagination({{
                             totalPages: {num_pages},
-                            visiblePages: 3,
-                            first: '<<',
-                            prev: '<',
-                            next: '>',
-                            last: '>>',
+                            visiblePages: {visible_pages},
+                            first: '{pagination_labels_first}',
+                            prev: '{pagination_labels_prev}',
+                            next: '{pagination_labels_next}',
+                            last: '{pagination_labels_last}',
                             onPageClick: function (event, page) {{
                                 AmUpdatePage(page);
                             }}
@@ -383,11 +395,11 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
                     $(window).on('load', function () {{
                         $('#pagination').twbsPagination({{
                             totalPages: {num_pages},
-                            visiblePages: 3,
-                            first: '<<',
-                            prev: '<',
-                            next: '>',
-                            last: '>>',
+                            visiblePages: {visible_pages},
+                            first: '{pagination_labels_first}',
+                            prev: '{pagination_labels_prev}',
+                            next: '{pagination_labels_next}',
+                            last: '{pagination_labels_last}',
                             onPageClick: function (event, page) {{
                                 AmUpdatePage(page);
                             }}
@@ -404,7 +416,16 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
             td_columns=td_columns,
             update_columns=update_columns,
             search_default=search_default,
-            filters=filters
+            filters=filters,
+            detail_pk=detail_pk,
+            detail_pk_arg=detail_pk_arg,
+            pagination_labels_last=self.pagination_labels['last'],
+            pagination_labels_first=self.pagination_labels['first'],
+            pagination_labels_prev=self.pagination_labels['prev'],
+            pagination_labels_next=self.pagination_labels['next'],
+            visible_pages=self.visible_pages,
+            awesome_css=static('awesome_mixins/css/list_view.css'),
+            awesome_twbs=static('awesome_mixins/js/twbs-pagination/jquery.twbsPagination.min.js')
         ))
 
     def get_json_list_name(self):
@@ -457,6 +478,9 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
                 fields.reverse()
             att = self.do_serialize(fields, obj)
             result[line['lookup']] = att
+
+        if self.detail_url:
+            result['id'] = obj.id
         return result
 
     def do_serialize(self, fields, obj):
@@ -481,6 +505,7 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
                 'div_header': 'box-header',
                 'div_body': 'box-body table-responsive no-padding',
                 'div_footer': 'box-footer clearfix',
+                'pagination': 'pagination'
             }
         }
 
@@ -501,6 +526,7 @@ class ListMixin(ListView, AccessMixin, BaseListView, AjaxResponseMixin, JSONResp
                 'div_header': self.css_div_header if self.css_div_header else '',
                 'div_body': self.css_div_body if self.css_div_body else '',
                 'div_footer': self.css_div_footer if self.css_div_footer else '',
+                'pagination': self.css_pagination if self.css_pagination else ''
             }
             if key:
                 return data[key]
